@@ -412,10 +412,12 @@ block_order = function(res, N = length(res)) {
   order(x)
 }
 
-#' @description The function `fuse()` extracts and runs code from code chunks
-#'   and inline code expressions in R Markdown, and interweaves the results with
-#'   the rest of text in the input, which is similar to what `knitr::knit()` and
-#'   `rmarkdown::render()` do. It also works on R scripts in a way similar to
+#' @description The function `fuse()` runs code from code chunks and inline code
+#'   expressions in R Markdown, interweaves the results with the rest of text in
+#'   the input to intermediate Markdown output (which is similar to what
+#'   `knitr::knit()` does), and renders the Markdown output through `mark()` to
+#'   the final output format, such as HTML or LaTeX (similar to
+#'   `rmarkdown::render()`). It also works on R scripts in a way similar to
 #'   `knitr::spin()`. The function `fiss()` extracts code from the input, and is
 #'   similar to `knitr::purl()`.
 #' @rdname mark
@@ -426,6 +428,8 @@ block_order = function(res, N = length(res)) {
 #'   a global [option][options] `litedown.progress.delay` (the default is `2`).
 #'   THe progress bar output can be set via a global option
 #'   `litedown.progress.output` (the default is [stderr()]).
+#' @note For `fuse()`, you can generate the intermediate Markdown output via
+#'   `output = '.md'` or `output = 'markdown'` without further calling `mark()`.
 #' @seealso [sieve()], for the syntax of R scripts to be passed to [fuse()].
 #' @export
 #' @examples
@@ -774,6 +778,8 @@ fuse_code = function(x, blocks) {
   if (is.logical(res_show)) res_show = if (res_show) 'markup' else 'hide'
 
   l1 = x$code_start  # starting line number of the whole code chunk
+  # filter the results if desired
+  if (!is.null(opts$filter)) res = match.fun(opts$filter)(res)
   # generate markdown output
   out = lapply(res, function(x) {
     type = grep_sub('^record_', '', class(x))[1]
@@ -800,8 +806,8 @@ fuse_code = function(x, blocks) {
     } else {
       a = opts[[paste0('attr.', type)]]
       if (type == 'source') {
-        # use engine name as class name; when `a` contains class names, prefix language-
-        if (!any(grepl('(^| )[.]', a))) a = c(paste0('.',  lang), a)
+        # use engine name as class name when `a` is not provided
+        if (is.null(a)) a = paste0('.',  lang)
         # add line numbers
         if (is_roaming()) a = c(a, lineno_attr(NA, l1 + l2 - 1))
       } else {
@@ -935,7 +941,9 @@ continue_block = function(e1_open, e1_end, e2) {
   if (length(e2) != 2 || e2[1] != '') return(FALSE)
   if ((e2_open <- e2[2]) == e1_end) return(TRUE)
   e3 = sub(' data-start="[0-9]+"', '', c(e1_open, e2_open))
-  e3[1] == e3[2]
+  if (e3[1] == e3[2]) return(TRUE)
+  # remove attributes of message blocks and see if they can be collapsed
+  sub(' \\{[.]plain [.](message|warning|error)}', '', e2_open) == e1_end
 }
 
 new_source = function(x) {
@@ -950,6 +958,28 @@ new_asis = function(x, raw = FALSE) {
   if (raw) raw_string(res) else res
 }
 
+# interleave text and plot output, e.g., t t t p p p -> t p t p t p, or t t t t
+# p p -> t t p t t p
+interleave = function(res) {
+  p = match(c('record_output', 'record_plot'), sapply(res, function(x) class(x)[1]))
+  if (any(is.na(p))) {
+    warning('Both text and plot output must be present in results to be interleaved.')
+    return(res)
+  }
+  x1 = res[[p[1]]]; n1 = length(x1)
+  x2 = res[[p[2]]]; n2 = length(x2)
+  n = n1 / n2
+  if (n < 1) return(res)
+  if (n1 %% n2 != 0) stop(
+    'Length of text output (', n1, ') is not multiple of the number of plots (', n2, ').'
+  )
+  # interleave text and plot output: one (chunk of) text followed by one plot
+  mix = unlist(lapply(seq_len(n2), function(i) {
+    list(new_output(x1[(i - 1) * n + 1:n]), new_plot(x2[i]))
+  }), recursive = FALSE)
+  append(res[-p], mix, p[1] - 1)
+}
+
 #' Mark a character vector as raw output
 #'
 #' This function should be called inside a code chunk, and its effect is the
